Reports
=======

This application comes with a report model that will store statistics about
the report, how many entries were added, failed, existed already..

It will also store a copy of the original CSV file and a failed entries CSV
that you can use to know what entries failed and fix them.
